==> tosspayments_sdk_flutter-0.0.8.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:example/screens/home.dart';
import 'package:example/screens/payment.dart';
import 'package:example/screens/result.dart';

void main() {
  runApp(const TosspaymentsSampleApp());
}

class TosspaymentsSampleApp extends StatelessWidget {
  const TosspaymentsSampleApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Tosspayments Flutter Sample',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const TosspaymentsSampleHome(title: 'Tosspayments Flutter Sample'),
    );
  }
}

class TosspaymentsSampleHome extends StatefulWidget {
  const TosspaymentsSampleHome({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  State<TosspaymentsSampleHome> createState() => _TosspaymentsSampleHomeState();
}

class _TosspaymentsSampleHomeState extends State<TosspaymentsSampleHome> {
  static const Color primaryColor = Color(0xf0064FF);

  @override
  Widget build(BuildContext context) {
    SystemChrome.setSystemUIOverlayStyle(const SystemUiOverlayStyle(
      systemNavigationBarColor: Colors.transparent,
      statusBarColor: Colors.transparent,
    ));
    SystemChrome.setEnabledSystemUIMode(SystemUiMode.edgeToEdge);

    return GetMaterialApp(
      initialRoute: '/',
      theme: ThemeData(
        primaryColor: primaryColor,
      ),
      getPages: [
        GetPage(name: '/', page: () => Home()),
        GetPage(name: '/payment', page: () => Payment()),
        GetPage(name: '/result', page: () => Result()),

      ],
    );
  }
}

==> tosspayments_sdk_flutter-0.1.4.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:get/get.dart';
import 'package:example/screens/home.dart';
import 'package:example/screens/result.dart';

void main() {
  runApp(const TosspaymentsSampleApp());
}

class TosspaymentsSampleApp extends StatelessWidget {
  const TosspaymentsSampleApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Tosspayments Flutter Sample',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const TosspaymentsSampleHome(title: 'Tosspayments Flutter Sample'),
    );
  }
}

class TosspaymentsSampleHome extends StatefulWidget {
  const TosspaymentsSampleHome({Key? key, required this.title})
      : super(key: key);

  final String title;

  @override
  State<TosspaymentsSampleHome> createState() => _TosspaymentsSampleHomeState();
}

class _TosspaymentsSampleHomeState extends State<TosspaymentsSampleHome> {
  static const Color primaryColor = Color(0x0f0064ff);

  @override
  Widget build(BuildContext context) {
    SystemChrome.setSystemUIOverlayStyle(const SystemUiOverlayStyle(
      systemNavigationBarColor: Colors.transparent,
      statusBarColor: Colors.transparent,
    ));
    SystemChrome.setEnabledSystemUIMode(SystemUiMode.edgeToEdge);

    return GetMaterialApp(
      initialRoute: '/',
      theme: ThemeData(
        primaryColor: primaryColor,
      ),
      getPages: [
        GetPage(name: '/', page: () => const Home()),
        GetPage(name: '/result', page: () => const Result())
      ],
    );
  }
}
